package pizza;

import java.util.ArrayList;
import java.util.List;

public class Customer
{
	private String name;
	private final List<OrderedPizza> orderedPizzas;

	public Customer(String name) {
		this.name = name;
		this.orderedPizzas = new ArrayList<OrderedPizza>();
	}

	public Customer(String name, List<OrderedPizza> orderedPizzas) {
		this(name);
		this.orderedPizzas.addAll(orderedPizzas);
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public void addOrder(OrderedPizza pizza) {
		orderedPizzas.add(pizza);
	}

	public String getOrderSummary() {
		int totalPrice = 0;
		int pizzaPoints = 0;
		String result = "Order Record for " + getName() + "\n";
		for (int i = 0; i < orderedPizzas.size(); ++i) {
			OrderedPizza order = orderedPizzas.get(i);
			int orderPrice = order.getQuantity() * order.getPizza().priceInCent;
			if (order.getPizza().size == Pizza.SIZE_NORMAL) {
				pizzaPoints += order.getQuantity() * 10;
			} else if (order.getPizza().size == Pizza.SIZE_XXL) {
				pizzaPoints += order.getQuantity() * 15;
			}
			totalPrice += orderPrice;
			result += String.format("   %2d %-20s %6d\n", order.getQuantity(),
					order.getPizza().name, orderPrice);
		}
		result += String.format("   %-23s %6d\n", "Total", totalPrice);
		result += String.format("   %-23s %6d\n", "Free Normal Pizzas", pizzaPoints / 100);
		return result;
	}
}
