package pizza;

import java.awt.Font;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.List;

import javax.swing.DefaultComboBoxModel;
import javax.swing.GroupLayout;
import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JOptionPane;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;
import javax.swing.JTextField;
import javax.swing.LayoutStyle;

public class OrderWindow extends JFrame implements ActionListener
{
	private static final long serialVersionUID = 1L;

	JButton addBtn;
	private JScrollPane jScrollPane1;
	JTextField nameField;
	JButton newBtn;
	JTextArea outputArea;
	JComboBox pizzaCombo;
	JTextField quantityField;

	private Customer customer;

	public OrderWindow(List<Pizza> todaysPizzas) {
		createContents();
		fillTodaysPizza(todaysPizzas);
	}

	private void fillTodaysPizza(List<Pizza> todaysPizzas) {
		Object a[] = new Object[todaysPizzas.size()];
		for (int i=0; i < a.length; ++i) {
			a[i] = todaysPizzas.get(i);
		}
		pizzaCombo.setModel(new DefaultComboBoxModel(a));
	}

	private void createContents() {
		newBtn = new JButton();
		newBtn.setText("New Customer");
		newBtn.addActionListener(this);

		JLabel label1 = new JLabel();
		label1.setText("Customer Name:");

		nameField = new JTextField();

		JLabel label2 = new JLabel();
		label2.setText("Available Pizzas:");

		pizzaCombo = new JComboBox();

		JLabel label3 = new JLabel();
		label3.setText("Quantity:");

		quantityField = new JTextField();

		addBtn = new JButton();
		addBtn.setText("Add");
		addBtn.addActionListener(this);

		JLabel label4 = new JLabel();
		label4.setText("Order Output:");

		outputArea = new JTextArea();
		outputArea.setColumns(20);
		outputArea.setEditable(false);
		outputArea.setFont(new java.awt.Font(Font.MONOSPACED, 0, 12));
		outputArea.setRows(5);
		jScrollPane1 = new JScrollPane();
		jScrollPane1.setViewportView(outputArea);

		GroupLayout layout = new GroupLayout(getContentPane());
		getContentPane().setLayout(layout);
		layout.setHorizontalGroup(
				layout.createParallelGroup(GroupLayout.Alignment.LEADING)
				.addGroup(layout.createSequentialGroup()
						.addContainerGap()
						.addGroup(layout.createParallelGroup(GroupLayout.Alignment.LEADING)
								.addComponent(jScrollPane1, GroupLayout.DEFAULT_SIZE, 513, Short.MAX_VALUE)
								.addGroup(layout.createSequentialGroup()
										.addComponent(newBtn)
										.addPreferredGap(LayoutStyle.ComponentPlacement.UNRELATED)
										.addComponent(label1)
										.addPreferredGap(LayoutStyle.ComponentPlacement.RELATED)
										.addComponent(nameField, GroupLayout.DEFAULT_SIZE, 254, Short.MAX_VALUE))
										.addGroup(layout.createSequentialGroup()
												.addComponent(label2)
												.addGap(3, 3, 3)
												.addComponent(pizzaCombo, 0, 215, Short.MAX_VALUE)
												.addPreferredGap(LayoutStyle.ComponentPlacement.RELATED)
												.addComponent(label3)
												.addPreferredGap(LayoutStyle.ComponentPlacement.RELATED)
												.addComponent(quantityField, GroupLayout.PREFERRED_SIZE, 46, GroupLayout.PREFERRED_SIZE)
												.addPreferredGap(LayoutStyle.ComponentPlacement.RELATED)
												.addComponent(addBtn))
												.addComponent(label4))
												.addContainerGap())
		);
		layout.setVerticalGroup(
				layout.createParallelGroup(GroupLayout.Alignment.LEADING)
				.addGroup(layout.createSequentialGroup()
						.addContainerGap()
						.addGroup(layout.createParallelGroup(GroupLayout.Alignment.BASELINE)
								.addComponent(newBtn)
								.addComponent(label1)
								.addComponent(nameField, GroupLayout.PREFERRED_SIZE, GroupLayout.DEFAULT_SIZE, GroupLayout.PREFERRED_SIZE))
								.addPreferredGap(LayoutStyle.ComponentPlacement.RELATED)
								.addGroup(layout.createParallelGroup(GroupLayout.Alignment.BASELINE)
										.addComponent(pizzaCombo, GroupLayout.PREFERRED_SIZE, GroupLayout.DEFAULT_SIZE, GroupLayout.PREFERRED_SIZE)
										.addComponent(label2)
										.addComponent(addBtn)
										.addComponent(quantityField, GroupLayout.PREFERRED_SIZE, GroupLayout.DEFAULT_SIZE, GroupLayout.PREFERRED_SIZE)
										.addComponent(label3))
										.addPreferredGap(LayoutStyle.ComponentPlacement.RELATED)
										.addComponent(label4)
										.addPreferredGap(LayoutStyle.ComponentPlacement.RELATED)
										.addComponent(jScrollPane1, GroupLayout.DEFAULT_SIZE, 336, Short.MAX_VALUE)
										.addContainerGap())
		);

		pack();

		setTitle("FooBars Pizza");

		setDefaultCloseOperation(EXIT_ON_CLOSE);
		setLocationRelativeTo(null);
	}

	public void actionPerformed(ActionEvent e) {
		if (newBtn.equals(e.getSource())) {
			nameField.setText("");
			pizzaCombo.setSelectedIndex(0);
			quantityField.setText("1");
			outputArea.setText("");
			nameField.requestFocusInWindow();
			customer = null;
		} else if (addBtn.equals(e.getSource())) {
			if (nameField.getText().trim().equals("")) {
				JOptionPane.showMessageDialog(this, "Set customer name first.",
						"Error",
						JOptionPane.ERROR_MESSAGE);
				return;
			}
			if (pizzaCombo.getSelectedIndex() == -1) {
				JOptionPane.showMessageDialog(this, "No pizza selected.",
						"Error",
						JOptionPane.ERROR_MESSAGE);
				return;
			}
			int quantity = 0;
			try {
				quantity = Integer.parseInt(quantityField.getText().trim());
				if (quantity <= 0) {
					throw new NumberFormatException();
				}
			} catch (NumberFormatException ex) {
				JOptionPane.showMessageDialog(this,
						"Quantity must be greater than 0.",
						"Error", JOptionPane.ERROR_MESSAGE);
				return;
			}
			if (customer == null) {
				customer = new Customer(nameField.getText().trim());
			} else {
				customer.setName(nameField.getText().trim());
			}
			customer.addOrder(new OrderedPizza(quantity, (Pizza) pizzaCombo.getSelectedItem()));
			outputArea.setText(customer.getOrderSummary());
		}
	}
}
