package pizza;

import static org.hamcrest.Matchers.is;
import static org.junit.Assert.assertThat;

import java.awt.event.ActionEvent;
import java.util.Arrays;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;

public class FunctionalTest
{
	private static final Pizza PIZZA_A = new Pizza("A", 1000, Pizza.SIZE_NORMAL);
	private static final Pizza PIZZA_B = new Pizza("B", 500, Pizza.SIZE_CHILDRENS);
	private static final Pizza PIZZA_C = new Pizza("C", 1500, Pizza.SIZE_XXL);

	private OrderWindow window;

	@Before
	public void setup() {
		window = new OrderWindow(Arrays.asList(PIZZA_A, PIZZA_B, PIZZA_C));
	}

	@After
	public void teardown() {
		window.dispose();
		window = null;
	}

	@Test
	public void newBtnClicked_resetsUiToInitialState() {
		window.actionPerformed(new ActionEvent(window.newBtn, 0, ""));
		assertThat(window.nameField.getText(), is(""));
		assertThat(window.outputArea.getText(), is(""));
		assertThat(window.quantityField.getText(), is("1"));
	}

	@Test
	public void addBtnClicked_outputShouldBeGenerated() {
		window.actionPerformed(new ActionEvent(window.newBtn, 0, ""));
		window.nameField.setText("Max Mustermann");
		window.pizzaCombo.setSelectedIndex(0);
		window.actionPerformed(new ActionEvent(window.addBtn, 0, ""));
		String result = "Order Record for Max Mustermann\n"
				+ "    1 A                      1000\n"
				+ "   Total                     1000\n"
				+ "   Free Normal Pizzas           0\n";
		assertThat(window.outputArea.getText(), is(result));
	}

	@Test
	public void pizzaPoints_19NormalPizzasEquals1FreePizza() {
		window.nameField.setText("a");
		window.pizzaCombo.setSelectedIndex(0);
		window.quantityField.setText("19");
		window.actionPerformed(new ActionEvent(window.addBtn, 0, ""));
		String result = "Order Record for a\n"
				+ "   19 A                     19000\n"
				+ "   Total                    19000\n"
				+ "   Free Normal Pizzas           1\n";
		assertThat(window.outputArea.getText(), is(result));
	}

	@Test
	public void pizzaPoints_20NormalPizzasEquals2FreePizzas() {
		window.nameField.setText("a");
		window.pizzaCombo.setSelectedIndex(0);
		window.quantityField.setText("20");
		window.actionPerformed(new ActionEvent(window.addBtn, 0, ""));
		String result = "Order Record for a\n"
				+ "   20 A                     20000\n"
				+ "   Total                    20000\n"
				+ "   Free Normal Pizzas           2\n";
		assertThat(window.outputArea.getText(), is(result));
	}
}
